@@ -1,32 +1,24 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2019 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef FIELDGROUP_H
 #define FIELDGROUP_H
 
 #include "kcontacts_export.h"
+
+#include <QMap>
 #include <QSharedDataPointer>
 #include <QString>
-#include <QMap>
 
-namespace KContacts {
+class FieldGroupTest;
+
+namespace KContacts
+{
+class ParameterMap;
 
 /** @short Class that holds a FieldGroup for a contact.
  *  @since 5.3
@@ -35,6 +27,9 @@ class KCONTACTS_EXPORT FieldGroup
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const FieldGroup &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, FieldGroup &);
+    friend class VCardTool;
+    friend class ::FieldGroupTest;
+
 public:
     FieldGroup();
     FieldGroup(const FieldGroup &other);
@@ -52,8 +47,21 @@ public:
     void setValue(const QString &value);
     Q_REQUIRED_RESULT QString value() const;
 
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @deprecated Since 5.88 for lack of usage
+     */
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     void setParameters(const QMap<QString, QStringList> &params);
+#endif
+
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
+    /**
+     * @deprecated Since 5.88 for lack of usage
+     */
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
+#endif
 
     Q_REQUIRED_RESULT bool operator==(const FieldGroup &other) const;
     Q_REQUIRED_RESULT bool operator!=(const FieldGroup &other) const;
@@ -61,7 +69,11 @@ public:
     FieldGroup &operator=(const FieldGroup &other);
 
     Q_REQUIRED_RESULT QString toString() const;
+
 private:
+    void setParams(const ParameterMap &params);
+    Q_REQUIRED_RESULT ParameterMap params() const;
+
     class Private;
     QSharedDataPointer<Private> d;
 };
